
# Type: double


A real number that conforms to the xsd:double specification

URI: [https://example.com/test62/meta:types/Double](https://example.com/test62/meta:types/Double)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **float** |
